@@ -16,7 +16,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::XMP;
 
-$VERSION = '1.04';
+$VERSION = '1.12';
 
 sub ProcessXtra($$$);
 
@@ -128,11 +128,20 @@ sub ProcessXtra($$$);
 );
 
 # Microsoft Photo 1.2 schema properties (MP) (ref PH)
+# (also ref http://msdn.microsoft.com/en-us/library/windows/desktop/ee719905(v=vs.85).aspx)
 my %sRegions = (
-    STRUCT_NAME => 'Regions',
+    STRUCT_NAME => 'Microsoft Regions',
     NAMESPACE   => 'MPReg',
-    Rectangle => { },
+    NOTES => q{
+        Note that PersonLiveIdCID element is called PersonLiveCID according to the
+        Microsoft specification, but in practice their software actually writes
+        PersonLiveIdCID, so ExifTool uses this too.
+    },
+    Rectangle         => { },
     PersonDisplayName => { },
+    PersonEmailDigest => { },
+    PersonLiveIdCID   => { },  # (see http://130.15.24.88/exiftool/forum/index.php?topic=4274.msg20368#msg20368)
+    PersonSourceID    => { },
 );
 %Image::ExifTool::Microsoft::MP = (
     %Image::ExifTool::XMP::xmpTableDefaults,
@@ -146,19 +155,27 @@ my %sRegions = (
     RegionInfo => {
         Name => 'RegionInfoMP',
         Struct => {
-            STRUCT_NAME => 'RegionInfoMP',
+            STRUCT_NAME => 'Microsoft RegionInfo',
             NAMESPACE   => 'MPRI',
             Regions   => { Struct => \%sRegions, List => 'Bag' },
+            DateRegionsValid => {
+                Writable => 'date',
+                Shift => 'Time',
+                Groups => { 2 => 'Time'},
+                PrintConv => '$self->ConvertDateTime($val)',
+                PrintConvInv => '$self->InverseDateTime($val,undef,1)',
+            },
         },
     },
-    RegionInfoRegionsRectangle => {
-        Name => 'RegionRectangle',
-        Flat => 1,
-    },
-    RegionInfoRegionsPersonDisplayName => {
-        Name => 'RegionPersonDisplayName',
-        Flat => 1,
-    },
+    # remove "MP" from tag name (was added only to avoid conflict with XMP-mwg-rs:RegionInfo)
+    RegionInfoRegions                  => { Flat => 1, Name => 'RegionInfoRegions' },
+    RegionInfoDateRegionsValid         => { Flat => 1, Name => 'RegionInfoDateRegionsValid' },
+    # shorten flattened Regions tag names to make them easier to use
+    RegionInfoRegionsRectangle         => { Flat => 1, Name => 'RegionRectangle' },
+    RegionInfoRegionsPersonDisplayName => { Flat => 1, Name => 'RegionPersonDisplayName' },
+    RegionInfoRegionsPersonEmailDigest => { Flat => 1, Name => 'RegionPersonEmailDigest' },
+    RegionInfoRegionsPersonLiveIdCID   => { Flat => 1, Name => 'RegionPersonLiveIdCID' },
+    RegionInfoRegionsPersonSourceID    => { Flat => 1, Name => 'RegionPersonSourceID' },
 );
 
 # Xtra tags written in MP4 files written by Microsoft Windows Media Player
@@ -172,7 +189,7 @@ my %sRegions = (
         Tags extracted from the Microsoft "Xtra" atom of QuickTime videos.  Tag ID's
         are not shown because some are unruly GUID's.
     },
-    Absract                     => { },
+    Abstract                    => { },
     AcquisitionTime             => { Groups => { 2 => 'Time' } },
     AcquisitionTimeDay          => { Groups => { 2 => 'Time' } },
     AcquisitionTimeMonth        => { Groups => { 2 => 'Time' } },
@@ -428,7 +445,7 @@ my %sRegions = (
     '{F29F85E0-4FF9-1068-AB91-08002B27B3D9} 6'     => 'Comments',
     '{64440492-4C8B-11D1-8B70-080036B11A03} 11'    => {
         Name => 'Copyright',
-        Groups => { 2 => 'Copyright' },
+        Groups => { 2 => 'Author' },
     },
     '{56A3372E-CE9C-11D2-9F0E-006097C686F6} 2'     => 'Artist',
     '{56A3372E-CE9C-11D2-9F0E-006097C686F6} 4'     => 'AlbumTitle',
@@ -592,7 +609,7 @@ my %sRegions = (
     '{3F8472B5-E0AF-4DB2-8071-C53FE76AE7CE} 100'   => 'DueDate',
     '{C75FAA05-96FD-49E7-9CB4-9F601082D553} 100'   => 'EndDate',
     '{28636AA6-953D-11D2-B5D6-00C04FD918D0} 12'    => 'FileCount',
-    '{41CF5AE0-F75A-4806-BD87-59C7D9248EB9} 100'   => 'Filename',
+    '{41CF5AE0-F75A-4806-BD87-59C7D9248EB9} 100'   => 'WindowsFileName',
     '{67DF94DE-0CA7-4D6F-B792-053A3E4F03CF} 100'   => 'FlagColor',
     '{E3E0584C-B788-4A5A-BB20-7F5A44C9ACDD} 12'    => 'FlagStatus',
     '{9B174B35-40FF-11D2-A27E-00C04FC30871} 2'     => 'SpaceFree',
@@ -642,7 +659,7 @@ my %sRegions = (
     '{64440492-4C8B-11D1-8B70-080036B11A03} 36'    => 'EncodedBy',
     '{64440492-4C8B-11D1-8B70-080036B11A03} 22'    => 'Producers',
     '{64440492-4C8B-11D1-8B70-080036B11A03} 30'    => 'Publisher',
-    '{56A3372E-CE9C-11D2-9F0E-006097C686F6} 38'    => 'Subtitle',
+    '{56A3372E-CE9C-11D2-9F0E-006097C686F6} 38'    => 'SubTitle',
     '{64440492-4C8B-11D1-8B70-080036B11A03} 34'    => 'UserWebURL',
     '{64440492-4C8B-11D1-8B70-080036B11A03} 23'    => 'Writers',
     '{E3E0584C-B788-4A5A-BB20-7F5A44C9ACDD} 21'    => 'Attachments',
@@ -690,7 +707,7 @@ my %sRegions = (
     '{14B81DA1-0135-4D31-96D9-6CBFC9671A99} 33437' => 'F-stop',
     '{14B81DA1-0135-4D31-96D9-6CBFC9671A99} 37385' => 'FlashMode',
     '{14B81DA1-0135-4D31-96D9-6CBFC9671A99} 37386' => 'FocalLength',
-    '{A0E74609-B84D-4F49-B860-462BD9971F98} 100'   => '35mmFocalLength',
+    '{A0E74609-B84D-4F49-B860-462BD9971F98} 100'   => 'FocalLength35mm',
     '{14B81DA1-0135-4D31-96D9-6CBFC9671A99} 34855' => 'ISOSpeed',
     '{E6DDCAF7-29C5-4F0A-9A68-D19412EC7090} 100'   => 'LensMaker',
     '{E1277516-2B5F-4869-89B1-2E585BD38B7A} 100'   => 'LensModel',
@@ -740,12 +757,12 @@ my %sRegions = (
 # Reference: http://code.google.com/p/mp4v2/
 sub ProcessXtra($$$)
 {
-    my ($exifTool, $dirInfo, $tagTablePtr) = @_;
+    my ($et, $dirInfo, $tagTablePtr) = @_;
     my $dataPt = $$dirInfo{DataPt};
     my $dataPos = $$dirInfo{Base} || 0;
     my $dataLen = $$dirInfo{DataLen};
     my $pos = 0;
-    $exifTool->VerboseDir('Xtra', 0, $dataLen);
+    $et->VerboseDir('Xtra', 0, $dataLen);
     for (;;) {
         last if $pos + 4 > $dataLen;
         my $size = Get32u($dataPt, $pos); # (includes $size word)
@@ -754,7 +771,12 @@ sub ProcessXtra($$$)
         last if $tagLen + 18 > $size;
         my $tag = substr($$dataPt, $pos + 8, $tagLen);
         my $version = Get32u($dataPt, $pos + $tagLen + 8);
-        $version == 1 or $exifTool->WarnOnce('Unsupported Xtra version'), next;
+        # (have seen a vers=2 type=8 tag that seems to work just like vers=1 - PH)
+        if ($version > 2) {
+            $et->WarnOnce("Unsupported Xtra version ($version)");
+            $pos += $size;
+            next;
+        }
         # (stored value includes size of $valLen and $valType, so subtract 6)
         my $valLen  = Get32u($dataPt, $pos + $tagLen + 12) - 6;
         last if $tagLen + $valLen + 18 > $size;
@@ -767,7 +789,7 @@ sub ProcessXtra($$$)
         SetByteOrder('II');
         if ($valType == 8) {
             $format = 'Unicode';
-            $val = $exifTool->Decode($val, 'UCS2');
+            $val = $et->Decode($val, 'UCS2');
         } elsif ($valType == 19 and $valLen == 8) {
             $format = 'int64u';
             $val = Get64u(\$val, 0);
@@ -787,7 +809,7 @@ sub ProcessXtra($$$)
             require Image::ExifTool::FlashPix;
             my $vPos = $valPos; # (necessary because ReadFPXValue updates this)
             # read entry as a VT_VARIANT (use FlashPix module for this)
-            $val = Image::ExifTool::FlashPix::ReadFPXValue($exifTool, $dataPt, $vPos,
+            $val = Image::ExifTool::FlashPix::ReadFPXValue($et, $dataPt, $vPos,
                    Image::ExifTool::FlashPix::VT_VARIANT(), $valPos+$valLen, 1);
         } else {
             $format = "Unknown($valType)";
@@ -795,7 +817,7 @@ sub ProcessXtra($$$)
         SetByteOrder('MM'); # back to native QuickTime byte ordering
         
         if ($tagLen > 0 and $valLen > 0) {
-            my $tagInfo = $exifTool->GetTagInfo($tagTablePtr, $tag);
+            my $tagInfo = $et->GetTagInfo($tagTablePtr, $tag);
             unless ($tagInfo) {
                 # generate tag information for unrecognized tags
                 my $name = $tag;
@@ -806,13 +828,14 @@ sub ProcessXtra($$$)
                     AddTagToTable($tagTablePtr, $tag, $tagInfo);
                 }
             }
-            $exifTool->HandleTag($tagTablePtr, $tag, $val,
+            $et->HandleTag($tagTablePtr, $tag, $val,
                 TagInfo => $tagInfo,
                 DataPt  => $dataPt,
                 DataPos => $dataPos,
                 Start   => $valPos,
                 Size    => $valLen,
                 Format  => $format,
+                Extra   => " vers=$version type=$valType",
             );
         }
         $pos += $size;  # step to next entry
@@ -839,7 +862,7 @@ Microsoft-specific EXIF and XMP tags.
 
 =head1 AUTHOR
 
-Copyright 2003-2012, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2014, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
