@@ -7,6 +7,8 @@
 #
 # References:   1) http://www.ozhiker.com/electronics/pjmt/jpeg_info/ricoh_mn.html
 #               2) http://homepage3.nifty.com/kamisaka/makernote/makernote_ricoh.htm
+#               3) Tim Gray private communication (GR)
+#               4) https://github.com/atotto/ricoh-theta-tools/
 #------------------------------------------------------------------------------
 
 package Image::ExifTool::Ricoh;
@@ -16,7 +18,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.18';
+$VERSION = '1.27';
 
 sub ProcessRicohText($$$);
 sub ProcessRicohRMETA($$$);
@@ -34,6 +36,7 @@ my %ricohLensIDs = (
     'RL3' => 'Ricoh Lens P10 28-300mm F3.5-5.6 VC',
     'RL5' => 'GR Lens A12 28mm F2.5',
     'RL8' => 'Mount A12',
+    'RL6' => 'Ricoh Lens A16 24-85mm F3.5-5.5',
 );
 
 %Image::ExifTool::Ricoh::Main = (
@@ -66,8 +69,8 @@ my %ricohLensIDs = (
             Name => 'InternalSerialNumber',
             Writable => 'undef',
             Count => 16,
-            PrintConv => 'unpack("H*", $val)',
-            PrintConvInv => 'pack("H*", $val)',
+            ValueConv => 'unpack("H*", $val)',
+            ValueConvInv => 'pack("H*", $val)',
         },
     ],
     0x0e00 => {
@@ -76,23 +79,319 @@ my %ricohLensIDs = (
         Description => 'Print Image Matching',
         SubDirectory => { TagTable => 'Image::ExifTool::PrintIM::Main' },
     },
-    0x1001 => {
+    0x1000 => { #3
+        Name => 'RecordingFormat',
+        Writable => 'int16u',
+        PrintConv => {
+            2 => 'JPEG',
+            3 => 'DNG',
+        },
+    },            
+    0x1001 => [{
         Name => 'ImageInfo',
+        Condition => '$format ne "int16u"',
         SubDirectory => { TagTable => 'Image::ExifTool::Ricoh::ImageInfo' },
-    },
-    0x1003 => {
+    },{ #3
+        Name => 'ExposureProgram',
+        Writable => 'int16u',
+        Notes => 'GR',
+        PrintConv => {
+            1 => 'Auto',
+            2 => 'Program AE',
+            3 => 'Aperture-priority AE',
+            4 => 'Shutter speed priority AE',
+            5 => 'Shutter/aperture priority AE', # TAv
+            6 => 'Manual',
+            7 => 'Movie', #PH
+        },
+    }],
+    0x1002 => { #3
+        Name => 'DriveMode',
+        Condition => '$format eq "int16u"',
+        Notes => 'valid only for some models',
+        Writable => 'int16u',
+        PrintConv => {
+            0 => 'Single-frame',
+            1 => 'Continuous',
+            8 => 'AF-priority Continuous',
+        },
+    },            
+    0x1003 => [{
         Name => 'Sharpness',
+        Condition => '$format ne "int16u"',
         Writable => 'int32u',
         PrintConv => {
             0 => 'Sharp',
             1 => 'Normal',
             2 => 'Soft',
         },
+    },{ #3
+        Name => 'WhiteBalance',
+        Writable => 'int16u',
+        Notes => 'GR',
+        PrintConv => {
+            0 => 'Auto',
+            1 => 'Multi-P Auto',
+            2 => 'Daylight',
+            3 => 'Cloudy',
+            4 => 'Incandescent 1',
+            5 => 'Incandescent 2',
+            6 => 'Daylight Fluorescent',
+            7 => 'Neutral White Fluorescent',
+            8 => 'Cool White Fluorescent',
+            9 => 'Warm White Fluorescent',
+            10 => 'Manual',
+            11 => 'Kelvin',
+        },
+    }],
+    0x1004 => { #3
+        Name => 'WhiteBalanceFineTune',
+        Condition => '$format eq "int16u"',
+        Format => 'int16s',
+        Writable => 'int16u',
+        Notes => q{
+            2 numbers: amount of adjustment towards Amber and Green.  Not valid for all
+            models
+        },
     },
+    # 0x1005 int16u - 5
+    0x1006 => { #3
+        Name => 'FocusMode',
+        Writable => 'int16u',
+        PrintConv => {
+            1 => 'Manual',
+            2 => 'Multi AF',
+            3 => 'Spot AF',
+            4 => 'Snap',
+            5 => 'Infinity',
+            7 => 'Face Detect', #PH
+            8 => 'Subject Tracking',
+            9 => 'Pinpoint AF',
+            10 => 'Movie', #PH
+        },
+    },
+    0x1007 => { #3
+        Name => 'AutoBracketing',
+        Writable => 'int16u',
+        PrintConv => {
+            0 => 'Off',
+            9 => 'AE',
+            11 => 'WB',
+            16 => 'DR', # (dynamic range)
+            17 => 'Contrast',
+            18 => 'WB2', # (selects two different WB presets besides normal)
+            19 => 'Effect',
+        },
+    },
+    0x1009 => { #3
+        Name => 'MacroMode',
+        Writable => 'int16u',
+        PrintConv => { 0 => 'Off', 1 => 'On' },
+    },
+    0x100a => { #3
+        Name => 'FlashMode',
+        Writable => 'int16u',
+        PrintConv => {
+            0 => 'Off',
+            1 => 'Auto, Fired',
+            2 => 'On',
+            3 => 'Auto, Fired, Red-eye reduction',
+            4 => 'Slow Sync',
+            5 => 'Manual',
+            6 => 'On, Red-eye reduction',
+            7 => 'Synchro, Red-eye reduction',
+            8 => 'Auto, Did not fire',
+        },
+    },
+    0x100b => { #3
+        Name => 'FlashExposureComp',
+        Writable => 'rational64s',
+        PrintConv => '$val ? sprintf("%+.1f",$val) : $val',
+        PrintConvInv => '$val',
+    },
+    0x100c => { #3
+        Name => 'ManualFlashOutput',
+        Writable => 'rational64s',
+        PrintConv => {
+               0 => 'Full',
+             -24 => '1/1.4',
+             -48 => '1/2',
+             -72 => '1/2.8',
+             -96 => '1/4',
+            -120 => '1/5.6',
+            -144 => '1/8',
+            -168 => '1/11',
+            -192 => '1/16',
+            -216 => '1/22',
+            -240 => '1/32',
+            -288 => '1/64',
+        },
+    },
+    0x100d => { #3
+        Name => 'FullPressSnap',
+        Writable => 'int16u',
+        PrintConv => { 0 => 'Off', 1 => 'On' },
+    },
+    0x100e => { #3
+        Name => 'DynamicRangeExpansion',
+        Writable => 'int16u',
+        PrintConv => {
+            0 => 'Off',
+            3 => 'Weak',
+            4 => 'Medium',
+            5 => 'Strong',
+        },
+    },
+    0x100f => { #3
+        Name => 'NoiseReduction',
+        Writable => 'int16u',
+        PrintConv => {
+            0 => 'Off',
+            1 => 'Weak',
+            2 => 'Medium',
+            3 => 'Strong',
+        },
+    },
+    0x1010 => { #3
+        Name => 'ImageEffects',
+        Writable => 'int16u',
+        PrintConv => {
+            0 => 'Standard',
+            1 => 'Vivid',
+            3 => 'Black & White',
+            5 => 'B&W Toning Effect',
+            6 => 'Setting 1',
+            7 => 'Setting 2',
+            9 => 'High-contrast B&W',
+            10 => 'Cross Process',
+            11 => 'Positive Film',
+            12 => 'Bleach Bypass',
+            13 => 'Retro',
+            15 => 'Miniature',
+            17 => 'High Key',
+        },
+    },
+    0x1011 => { #3
+        Name => 'Vignetting',
+        Writable => 'int16u',
+        PrintConv => {
+            0 => 'Off',
+            1 => 'Low',
+            2 => 'Medium',
+            3 => 'High',
+        },
+    },
+    0x1012 => { #PH
+        Name => 'Contrast',
+        Writable => 'int32u',
+        Format => 'int32s', #3 (high-contrast B&W also has -1 and -2 settings)
+        PrintConv => {
+            OTHER => sub { shift },
+            2147483647 => 'MAX', #3 (high-contrast B&W effect MAX setting)
+        },
+    },
+    0x1013 => { Name => 'Saturation', Writable => 'int32u' }, #PH
+    0x1014 => { Name => 'Sharpness',  Writable => 'int32u' }, #3
+    0x1015 => { #3
+        Name => 'ToningEffect',
+        Writable => 'int16u',
+        PrintConv => {
+            0 => 'Off',
+            1 => 'Sepia',
+            2 => 'Red',
+            3 => 'Green',
+            4 => 'Blue',
+            5 => 'Purple',
+            6 => 'B&W',
+            7 => 'Color',
+        },
+    },
+    0x1016 => { #3
+        Name => 'HueAdjust',
+        Writable => 'int16u',
+        PrintConv => {
+            0 => 'Off',
+            1 => 'Basic',
+            2 => 'Magenta',
+            3 => 'Yellow',
+            4 => 'Normal',
+            5 => 'Warm',
+            6 => 'Cool',
+        },
+    },
+    0x1017 => { #3
+        Name => 'WideAdapter',
+        Writable => 'int16u',
+        PrintConv => {
+            0 => 'Not Attached',
+            2 => 'Attached', # (21mm)
+        },
+    },
+    0x1018 => { #3
+        Name => 'CropMode35mm',
+        Writable => 'int16u',
+        PrintConv => { 0 => 'Off', 1 => 'On' },
+    },
+    0x1019 => { #3
+        Name => 'NDFilter',
+        Writable => 'int16u',
+        PrintConv => { 0 => 'Off', 1 => 'On' },
+    },
+    0x101a => { Name => 'WBBracketShotNumber', Writable => 'int16u' }, #3
+    # 0x1100 - related to DR correction (ref 3)
+    0x1307 => { Name => 'ColorTempKelvin',     Writable => 'int32u' }, #3
+    0x1308 => { Name => 'ColorTemperature',    Writable => 'int32u' }, #3
+    0x1500 => { #3
+        Name => 'FocalLength',
+        Writable => 'rational64u',
+        PrintConv => 'sprintf("%.1f mm",$val)',
+        PrintConvInv => '$val=~s/\s*mm$//;$val',
+    },
+    0x1200 => { #3
+        Name => 'AFStatus',
+        Writable => 'int16u',
+        PrintConv => {
+            0 => 'Out of Focus',
+            1 => 'In Focus',
+        },
+    },
+    # 0x1201-0x1204 - related to focus points (ref 3)
+    0x1201 => { #PH (NC)
+        Name => 'AFAreaXPosition1',
+        Writable => 'int32u',
+        Notes => 'manual AF area position in a 1280x864 image',
+    },
+    0x1202 => { Name => 'AFAreaYPosition1', Writable => 'int32u' }, #PH (NC)
+    0x1203 => { #PH (NC)
+        Name => 'AFAreaXPosition',
+        Writable => 'int32u',
+        Notes => 'manual AF area position in the full image',
+        # (coordinates change to correspond with smaller image
+        #  when recording reduced-size JPEG)
+    },
+    0x1204 => { Name => 'AFAreaYPosition', Writable => 'int32u' }, #PH (NC)
+    0x1205 => { #3
+        Name => 'AFAreaMode',
+        Writable => 'int16u',
+        PrintConv => {
+            0 => 'Auto',
+            2 => 'Manual',
+        },
+    },
+    0x1601 => { Name => 'SensorWidth',  Writable => 'int32u' }, #3
+    0x1602 => { Name => 'SensorHeight', Writable => 'int32u' }, #3
+    0x1603 => { Name => 'CroppedImageWidth',  Writable => 'int32u' }, #3
+    0x1604 => { Name => 'CroppedImageHeight', Writable => 'int32u' }, #3
+    # 0x1700 - Composite? (0=normal image, 1=interval composite, 2=multi-exposure composite) (ref 3)
+    # 0x1703 - 0=normal, 1=final composite (ref 3)
+    # 0x1704 - 0=normal, 2=final composite (ref 3)
     0x2001 => [
         {
             Name => 'RicohSubdir',
-            Condition => '$self->{Model} !~ /^Caplio RR1\b/',
+            Condition => q{
+                $self->{Model} !~ /^Caplio RR1\b/ and
+                ($format ne 'int32u' or $count != 1)
+            },
             SubDirectory => {
                 Validate => '$val =~ /^\[Ricoh Camera Info\]/',
                 TagTable => 'Image::ExifTool::Ricoh::Subdir',
@@ -100,6 +399,17 @@ my %ricohLensIDs = (
                 ByteOrder => 'BigEndian',
             },
         },
+        {
+            Name => 'RicohSubdirIFD',
+            # the CX6 and GR Digital 4 write an int32u pointer in AVI videos -- doh!
+            Condition => '$self->{Model} !~ /^Caplio RR1\b/',
+            Flags => 'SubIFD',
+            SubDirectory => {
+                TagTable => 'Image::ExifTool::Ricoh::Subdir',
+                Start => '$val + 20', # (skip over "[Ricoh Camera Info]\0" header)
+                ByteOrder => 'BigEndian',
+            },
+        },
         {
             Name => 'RicohRR1Subdir',
             SubDirectory => {
@@ -112,6 +422,15 @@ my %ricohLensIDs = (
             },
         },
     ],
+    0x4001 => {
+        Name => 'ThetaSubdir',
+        Groups => { 1 => 'MakerNotes' },    # SubIFD needs group 1 set
+        Flags => 'SubIFD',
+        SubDirectory => {
+            TagTable => 'Image::ExifTool::Ricoh::ThetaSubdir',
+            Start => '$val',
+        },
+    },
 );
 
 # Ricoh image info (ref 2)
@@ -150,15 +469,15 @@ my %ricohLensIDs = (
     },
     28 => {
         Name => 'PreviewImageStart',
-        Format => 'int16u',
+        Format => 'int16u', # ha!  (only the lower 16 bits, even if > 0xffff)
         Flags => 'IsOffset',
         OffsetPair => 30,   # associated byte count tagID
         DataTag => 'PreviewImage',
         Protected => 2,
-        # prevent preview from being written to raw images
+        # prevent preview from being written to MakerNotes of DNG images
         RawConvInv => q{
             return $val if $$self{FILE_TYPE} eq "JPEG";
-            warn "Can't write PreviewImage to $$self{TIFF_TYPE} file\n";
+            warn "\n"; # suppress warning
             return undef;
         },
     },
@@ -170,7 +489,7 @@ my %ricohLensIDs = (
         Protected => 2,
         RawConvInv => q{
             return $val if $$self{FILE_TYPE} eq "JPEG";
-            warn "\n"; # suppress warning (already issued for PreviewImageStart)
+            warn "\n"; # suppress warning
             return undef;
         },
     },
@@ -218,6 +537,8 @@ my %ricohLensIDs = (
             7 => 800,
             8 => 1600,
             9 => 'Auto', #PH (? CX3)
+            10 => 3200, #PH (A16)
+            11 => '100 (Low)', #PH (A16)
         },
     },
     40 => {
@@ -235,7 +556,7 @@ my %ricohLensIDs = (
 );
 
 # Ricoh subdirectory tags (ref PH)
-# NOTE: this subdir is not currently writable because the offsets would require
+# NOTE: this subdir is currently not writable because the offsets would require
 # special code to handle the funny start location and base offset
 %Image::ExifTool::Ricoh::Subdir = (
     GROUPS => { 0 => 'MakerNotes', 2 => 'Camera' },
@@ -285,6 +606,31 @@ my %ricohLensIDs = (
     # 0x000E ProductionNumber? (ref 2) [no. zero for most models - PH]
 );
 
+
+# Ricoh Theta subdirectory tags - Contains orientation information (ref 4)
+%Image::ExifTool::Ricoh::ThetaSubdir = (
+    GROUPS => { 0 => 'MakerNotes', 2 => 'Camera' },
+    WRITE_PROC => \&Image::ExifTool::Exif::WriteExif,
+    CHECK_PROC => \&Image::ExifTool::Exif::CheckExif,
+    # 0x0001 => Unknown
+    # 0x0002 => Unknown
+    0x0003 => {
+        Name => 'Accelerometer',
+        Writable => 'rational64s',
+        Count => 2,
+    },
+    0x0004 => {
+        Name => 'Compass',
+        Writable => 'rational64u',
+    },
+    # 0x0005 => Unknown
+    # 0x0101 => Unknown - ISO Speed?
+    # 0x0102 => Unknown - F Number?
+    # 0x0103 => Unknown - Exposure?
+    # 0x0104 => Unknown - Serial Number?
+    # 0x0105 => Unknown - Serial Number?
+);
+
 # face detection information (ref PH, CX4)
 %Image::ExifTool::Ricoh::FaceInfo = (
     GROUPS => { 0 => 'MakerNotes', 2 => 'Camera' },
@@ -471,6 +817,10 @@ my %ricohLensIDs = (
         15 => 'NW',
         16 => 'NNW',
     } },
+    _audio => {
+        Name => 'SoundFile',
+        Notes => 'audio data recorded in JPEG images by the G700SE',
+    },
 );
 
 # information stored in Ricoh AVI images (ref PH)
@@ -512,6 +862,14 @@ my %ricohLensIDs = (
         ValueConv => '$val=~s/\s*:.*//; $val',
         PrintConv => \%ricohLensIDs,
     },
+    RicohPitch => {
+        Require => 'Ricoh:Accelerometer',
+        ValueConv => 'my @v = split(" ",$val); $v[1]',
+    },
+    RicohRoll => {
+        Require => 'Ricoh:Accelerometer',
+        ValueConv => 'my @v = split(" ",$val); $v[0] <= 180 ? $v[0] : $v[0] - 360',
+    },
 );
 
 # add our composite tags
@@ -526,71 +884,93 @@ Image::ExifTool::AddCompositeTags('Image::ExifTool::Ricoh');
 # Returns: 1 on success, otherwise returns 0 and sets a Warning
 sub ProcessRicohText($$$)
 {
-    my ($exifTool, $dirInfo, $tagTablePtr) = @_;
+    my ($et, $dirInfo, $tagTablePtr) = @_;
     my $dataPt = $$dirInfo{DataPt};
     my $dataLen = $$dirInfo{DataLen};
     my $dirStart = $$dirInfo{DirStart} || 0;
     my $dirLen = $$dirInfo{DirLen} || $dataLen - $dirStart;
-    my $verbose = $exifTool->Options('Verbose');
+    my $verbose = $et->Options('Verbose');
 
     my $data = substr($$dataPt, $dirStart, $dirLen);
     return 1 if $data =~ /^\0/;     # blank Ricoh maker notes
     # validate text maker notes
     unless ($data =~ /^(Rev|Rv)/) {
-        $exifTool->Warn('Bad Ricoh maker notes');
+        $et->Warn('Bad Ricoh maker notes');
         return 0;
     }
     while ($data =~ m/([A-Z][a-z]{1,2})([0-9A-F]+);/sg) {
         my $tag = $1;
         my $val = $2;
-        my $tagInfo = $exifTool->GetTagInfo($tagTablePtr, $tag);
+        my $tagInfo = $et->GetTagInfo($tagTablePtr, $tag);
         if ($verbose) {
-            $exifTool->VerboseInfo($tag, $tagInfo,
+            $et->VerboseInfo($tag, $tagInfo,
                 Table  => $tagTablePtr,
                 Value  => $val,
             );
         }
         unless ($tagInfo) {
-            next unless $exifTool->{OPTIONS}->{Unknown};
+            next unless $$et{OPTIONS}{Unknown};
             $tagInfo = {
                 Name => "Ricoh_Text_$tag",
                 Unknown => 1,
                 PrintConv => 'length($val) > 60 ? substr($val,0,55) . "[...]" : $val',
             };
             # add tag information to table
-            Image::ExifTool::AddTagToTable($tagTablePtr, $tag, $tagInfo);
+            AddTagToTable($tagTablePtr, $tag, $tagInfo);
         }
-        $exifTool->FoundTag($tagInfo, $val);
+        $et->FoundTag($tagInfo, $val);
     }
     return 1;
 }
 
 #------------------------------------------------------------------------------
 # Process Ricoh APP5 RMETA information
-# Inputs: 0) ExifTool object reference
-#         1) Reference to directory information hash
-#         2) Pointer to tag table for this directory
+# Inputs: 0) ExifTool ref, 1) dirInfo ref, 2) tag table ref
 # Returns: 1 on success, otherwise returns 0 and sets a Warning
 sub ProcessRicohRMETA($$$)
 {
-    my ($exifTool, $dirInfo, $tagTablePtr) = @_;
+    my ($et, $dirInfo, $tagTablePtr) = @_;
     my $dataPt = $$dirInfo{DataPt};
     my $dirStart = $$dirInfo{DirStart};
     my $dataLen = length($$dataPt);
-    my $verbose = $exifTool->Options('Verbose');
+    my $dirLen = $dataLen - $dirStart;
+    my $verbose = $et->Options('Verbose');
 
-    $dataLen > 6 or $exifTool->Warn('Truncated Ricoh RMETA data'), return 0;
+    $et->VerboseDir('Ricoh RMETA') if $verbose;
+    $dirLen > 6 or $et->Warn('Truncated Ricoh RMETA data', 1), return 0;
     my $byteOrder = substr($$dataPt, $dirStart, 2);
-    SetByteOrder($byteOrder) or $exifTool->Warn('Bad Ricoh RMETA data'), return 0;
+    SetByteOrder($byteOrder) or $et->Warn('Bad Ricoh RMETA data', 1), return 0;
+    my $rmetaNum = Get16u($dataPt, $dirStart+4);
+    if ($rmetaNum != 0) {
+        # not sure how to recognize audio, so do it by checking for "RIFF" header
+        # and assume all subsequent RMETA segments are part of the audio data
+        # (but it looks like the int16u at $dirStart+6 is the next block number
+        # if the data is continued, or 0 for the last block)
+        $dirLen < 14 and $et->Warn('Short Ricoh RMETA block', 1), return 0;
+        my $audioLen = Get16u($dataPt, $dirStart+12);
+        $audioLen + 14 > $dirLen and $et->Warn('Truncated Ricoh RMETA audio data', 1), return 0;
+        my $buff = substr($$dataPt, $dirStart + 14, $audioLen);
+        if ($audioLen >= 4 and substr($buff, 0, 4) eq 'RIFF') {
+            $et->HandleTag($tagTablePtr, '_audio', \$buff);
+        } elsif ($$et{VALUE}{SoundFile}) {
+            ${$$et{VALUE}{SoundFile}} .= $buff;
+        } else {
+            $et->Warn('Unknown Ricoh RMETA type', 1);
+            return 0;
+        }
+        return 1;
+    }
+    # standard RMETA tag directory
     my (@tags, @vals, @nums, $valPos);
     my $pos = $dirStart + 6;
     while ($pos <= $dataLen - 4) {
         my $type = Get16u($dataPt, $pos);
         my $size = Get16u($dataPt, $pos + 2);
+        last unless $size;
         $pos += 4;
         $size -= 2;
         if ($size < 0 or $pos + $size > $dataLen) {
-            $exifTool->Warn('Corrupted Ricoh RMETA data');
+            $et->Warn('Corrupted Ricoh RMETA data', 1);
             last;
         }
         if ($type eq 1) {
@@ -614,35 +994,35 @@ sub ProcessRicohRMETA($$$)
         $pos += $size;
     }
     if (@tags or @vals) {
-        if (@tags != @vals) {
+        if (@tags < @vals) {
             my ($nt, $nv) = (scalar(@tags), scalar(@vals));
-            $exifTool->Warn("Number of tags ($nt) and values ($nv) differs in Ricoh RMETA");
+            $et->Warn("Fewer tags ($nt) than values ($nv) in Ricoh RMETA", 1);
         }
         # find next tag in null-delimited list
         # unpack numerical values from block of int16u values
         my ($tag, $name, $val);
         foreach $tag (@tags) {
             $val = shift @vals;
-            last unless defined $val;
+            $val = '' unless defined $val;
             ($name = $tag) =~ s/\b([a-z])/\U$1/gs;  # make capitalize all words
             $name =~ s/ (\w)/\U$1/g;                # remove special characters
             $name = 'RMETA_Unknown' unless length($name);
             my $num = shift @nums;
-            my $tagInfo = $exifTool->GetTagInfo($tagTablePtr, $tag);
+            my $tagInfo = $et->GetTagInfo($tagTablePtr, $tag);
             if ($tagInfo) {
                 # make sure print conversion is defined
-                $$tagInfo{PrintConv} = { } unless $$tagInfo{PrintConv};
+                $$tagInfo{PrintConv} = { } unless ref $$tagInfo{PrintConv} eq 'HASH';
             } else {
                 # create tagInfo hash
                 $tagInfo = { Name => $name, PrintConv => { } };
-                Image::ExifTool::AddTagToTable($tagTablePtr, $tag, $tagInfo);
+                AddTagToTable($tagTablePtr, $tag, $tagInfo);
             }
             # use string value directly if no numerical value
             $num = $val unless defined $num;
             # add conversion for this value (replacing any existing entry)
-            $tagInfo->{PrintConv}->{$num} = $val;
+            $tagInfo->{PrintConv}->{$num} = length $val ? $val : $num;
             if ($verbose) {
-                $exifTool->VerboseInfo($tag, $tagInfo,
+                $et->VerboseInfo($tag, $tagInfo,
                     Table   => $tagTablePtr,
                     Value   => $num,
                     DataPt  => $dataPt,
@@ -651,7 +1031,7 @@ sub ProcessRicohRMETA($$$)
                     Size    => length($val),
                 );
             }
-            $exifTool->FoundTag($tagInfo, $num);
+            $et->FoundTag($tagInfo, $num);
             $valPos += length($val) + 1;
         }
     }
@@ -677,7 +1057,7 @@ interpret Ricoh maker notes EXIF meta information.
 
 =head1 AUTHOR
 
-Copyright 2003-2011, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2014, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
@@ -690,6 +1070,10 @@ under the same terms as Perl itself.
 
 =back
 
+=head1 ACKNOWLEDGEMENTS
+
+Thanks to Tim Gray for his help decoding a number of tags for the Ricoh GR.
+
 =head1 SEE ALSO
 
 L<Image::ExifTool::TagNames/Ricoh Tags>,
