@@ -13,16 +13,54 @@
 package Image::ExifTool::Sigma;
 
 use strict;
-use vars qw($VERSION);
+use vars qw($VERSION %sigmaLensTypes);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.10';
+$VERSION = '1.13';
+
+# sigma LensType lookup (ref PH)
+%sigmaLensTypes = (
+    Notes => q{
+        Decimal values have been added to differentiate lenses which would otherwise
+        have the same LensType, and are used by the Composite LensID tag when
+        attempting to identify the specific lens model.
+    },
+    # 0 => 'Sigma 50mm F2.8 EX Macro', (0 used for other lenses too)
+    # 8 - 18-125mm LENSARANGE@18mm=22-4
+    16 => 'Sigma 18-50mm F3.5-5.6 DC',
+    129 => 'Sigma 14mm F2.8 EX Aspherical',
+    131 => 'Sigma 17-70mm F2.8-4.5 DC Macro',
+    145 => 'Sigma Lens (145)',
+    145.1 => 'Sigma 15-30mm F3.5-4.5 EX DG Aspherical',
+    145.2 => 'Sigma 18-50mm F2.8 EX DG', #(NC)
+    145.3 => 'Sigma 20-40mm F2.8 EX DG',
+    165 => 'Sigma 70-200mm F2.8 EX', # ...but what specific model?:
+    # 70-200mm F2.8 EX APO - Original version, minimum focus distance 1.8m (1999)
+    # 70-200mm F2.8 EX DG - Adds 'digitally optimized' lens coatings to reduce flare (2005)
+    # 70-200mm F2.8 EX DG Macro (HSM) - Minimum focus distance reduced to 1m (2006)
+    # 70-200mm F2.8 EX DG Macro HSM II - Improved optical performance (2007)
+    169 => 'Sigma 18-50mm F2.8 EX DC', #(NC)
+    581 => 'Sigma 18-50mm F2.8 EX DC Macro', # (SD1)
+    583 => 'Sigma 17-50mm F2.8 EX DC OS', # (SD1 kit)
+    1003 => 'Sigma 19mm F2.8', # (DP1 Merrill kit)
+    1004 => 'Sigma 30mm F2.8', # (DP2 Merrill kit)
+    1005 => 'Sigma 50mm F2.8 Macro', # (DP3 Merrill kit)
+    8900 => 'Sigma 70-300mm F4-5.6 DG OS', # (SD15)
+    'A100' => 'Sigma 24-70mm F2.8 DG Macro', # (SD15)
+    # 'FFFF' - seen this for a 28-70mm F2.8 lens
+);
 
 %Image::ExifTool::Sigma::Main = (
     WRITE_PROC => \&Image::ExifTool::Exif::WriteExif,
     CHECK_PROC => \&Image::ExifTool::Exif::CheckExif,
     WRITABLE => 'string',
     GROUPS => { 0 => 'MakerNotes', 2 => 'Camera' },
+    NOTES => q{
+        These tags are written by Sigma/Foveon cameras.  In the early days Sigma was
+        a class leader by releasing their maker note specification to the public,
+        but since then they have deviated from this standard and newer camera models
+        are less than consistent about their metadata formats.
+    },
     0x0002 => 'SerialNumber',
     0x0003 => 'DriveMode',
     0x0004 => 'ResolutionMode',
@@ -209,8 +247,11 @@ $VERSION = '1.10';
     0x001c => [ #PH
         {
             Name => 'PreviewImageSize',
-            Condition => '$$self{Model} ne "SIGMA SD1"',
-            Notes => 'PreviewImageStart for the SD1, PreviewImageSize for other models',
+            Condition => '$$self{Model} !~ /^SIGMA (SD1( Merrill)?|DP\d Merrill)$/',
+            Notes => q{
+                PreviewImageStart for the SD1 and Merrill models, and PreviewImageSize for
+                others
+            },
             Writable => 'int16u',
             Count => 2,
         },{
@@ -226,8 +267,11 @@ $VERSION = '1.10';
     0x001d => [ #PH
         {
             Name => 'MakerNoteVersion',
-            Condition => '$$self{Model} ne "SIGMA SD1"',
-            Notes => 'PreviewImageLength for the SD1, MakerNoteVersion for other models',
+            Condition => '$$self{Model} !~ /^SIGMA (SD1( Merrill)?|DP\d Merrill)$/',
+            Notes => q{
+                PreviewImageLength for the SD1 and Merrill models, and MakerNoteVersion for
+                others
+            },
             Writable => 'undef',
         },{
             Name => 'PreviewImageLength',
@@ -238,43 +282,80 @@ $VERSION = '1.10';
             Protected => 2,
         },
     ],
-    # 0x001e - int16u: 0, 4, 13 - flash mode?
+    # 0x001e - int16u: 0, 4, 13 - flash mode for other models?
+    0x001e => { #PH
+        Name => 'PreviewImageSize',
+        Condition => '$$self{Model} =~ /^SIGMA DP\d Merrill$/',
+        Notes => 'only valid for some models',
+        Writable => 'int16u',
+        Count => 2,
+    },
     0x001f => [ #PH
         {
             Name => 'AFPoint', # (NC -- invalid for SD9,SD14?)
-            Condition => '$$self{Model} ne "SIGMA SD1"',
-            Notes => 'MakerNoteVersion for the SD1, AFPoint for other models',
+            Condition => '$$self{Model} !~ /^SIGMA (SD1( Merrill)?|DP\d Merrill)$/',
+            Notes => 'MakerNoteVersion for the SD1 and Merrill models, and AFPoint for others',
             # values: "", "Center", "Center,Center", "Right,Right"
         },{
             Name => 'MakerNoteVersion',
             Writable => 'undef',
         },
     ],
-    # 0x0020-21 - string: " "
+    # 0x0020 - string: " " for most models, or int16u: 4 for the DP3 Merrill
+    # 0x0021 - string: " " for most models, or int8u[2]: '3 3' for the DP3 Merrill
     0x0022 => { #PH (NC)
         Name => 'FileFormat',
-        Condition => '$$self{Model} ne "SIGMA SD1"',
-        Notes => 'models other than the SD1',
+        Condition => '$$self{Model} !~ /^SIGMA (SD1( Merrill)?|DP\d Merrill)$/',
+        Notes => 'models other than the SD1 and Merrill models',
         # values: "JPG", "JPG-S", "JPG-P", "X3F", "X3F-S"
     },
     # 0x0023 - string: "", 10, 83, 131, 145, 150, 152, 169
     0x0024 => { # (invalid for SD9,SD14?)
         Name => 'Calibration',
-        Condition => '$$self{Model} ne "SIGMA SD1"',
-        Notes => 'models other than the SD1',
+        Condition => '$$self{Model} !~ /^SIGMA (SD1( Merrill)?|DP\d Merrill)$/',
+        Notes => 'models other than the SD1 and Merrill models',
     },
     # 0x0025 - string: "", "0.70", "0.90"
     # 0x0026-2b - int32u: 0
     0x0026 => { #PH (NC)
         Name => 'FileFormat',
-        Condition => '$$self{Model} eq "SIGMA SD1"',
-        Notes => 'SD1 only',
+        Condition => '$$self{Model} =~ /^SIGMA (SD1( Merrill)?|DP\d Merrill)$/',
+        Notes => 'SD1 and Merrill models only',
+    },
+    0x0027 => { #PH
+        Name => 'LensType',
+        Condition => '$$self{Model} =~ /^SIGMA (SD1( Merrill)?|DP\d Merrill)$/',
+        Notes => 'SD1 and Merrill models only',
+        SeparateTable => 'LensType',
+        ValueConvInv => '$val=~s/\.\d+$//; $val', # (truncate decimal part)
+        PrintConv => \%sigmaLensTypes,
+    },
+    0x002a => { #PH
+        Name => 'LensFocalRange',
+        Condition => '$$self{Model} =~ /^SIGMA (SD1( Merrill)?|DP\d Merrill)$/',
+        Notes => 'SD1 and Merrill models only',
+        Writable => 'rational64u',
+        Count => 2,
+        PrintConv => '$val=~s/ / to /; $val',
+        PrintConvInv => '$val=~s/to /; $val',
+    },
+    0x002b => { #PH
+        Name => 'LensMaxApertureRange',
+        # for most models this gives the max aperture at the long/short focal lengths,
+        # but for some models this gives the min/max aperture
+        Condition => '$$self{Model} =~ /^SIGMA (SD1( Merrill)?|DP\d Merrill)$/',
+        Notes => 'SD1 and Merrill models only',
+        Writable => 'rational64u',
+        Count => 2,
+        PrintConv => '$val=~s/ / to /; $val',
+        PrintConvInv => '$val=~s/to /; $val',
     },
     0x002c => { #PH
         Name => 'ColorMode',
-        Condition => '$$self{Model} ne "SIGMA SD1"',
-        Notes => 'models other than the SD1',
+        Condition => '$format eq "int32u"',
+        Notes => 'not valid for some models',
         Writable => 'int32u',
+        # this tag written by Sigma Photo Pro even for cameras that write 'n/a' here
         PrintConv => {
             0 => 'n/a',
             1 => 'Sepia',
@@ -284,6 +365,7 @@ $VERSION = '1.10';
             5 => 'Neutral',
             6 => 'Portrait',
             7 => 'Landscape',
+            8 => 'FOV Classic Blue',
         },
     },
     # 0x002d - int32u: 0
@@ -292,11 +374,11 @@ $VERSION = '1.10';
     0x0030 => [ #PH
         {
             Name => 'LensApertureRange',
-            Condition => '$$self{Model} ne "SIGMA SD1"',
+            Condition => '$$self{Model} !~ /^SIGMA (SD1( Merrill)?|DP\d Merrill)$/',
             Notes => q{
-                Calibration for the SD1, LensApertureRange for other models.  Note that
-                LensApertureRange changes with focal length, and some models report the
-                maximum aperture here
+                Calibration for the SD1 and Merrill models, and LensApertureRange for
+                others. Note that LensApertureRange changes with focal length, and some
+                models report the maximum aperture here
             },
         },{
             Name => 'Calibration',
@@ -304,8 +386,8 @@ $VERSION = '1.10';
     ],
     0x0031 => { #PH
         Name => 'FNumber',
-        Condition => '$$self{Model} ne "SIGMA SD1"',
-        Notes => 'models other than the SD1',
+        Condition => '$$self{Model} !~ /^SIGMA (SD1( Merrill)?|DP\d Merrill)$/',
+        Notes => 'models other than the SD1 and Merrill models',
         Writable => 'rational64u',
         PrintConv => 'sprintf("%.1f",$val)',
         PrintConvInv => '$val',
@@ -313,8 +395,8 @@ $VERSION = '1.10';
     },
     0x0032 => { #PH
         Name => 'ExposureTime',
-        Condition => '$$self{Model} ne "SIGMA SD1"',
-        Notes => 'models other than the SD1',
+        Condition => '$$self{Model} !~ /^SIGMA (SD1( Merrill)?|DP\d Merrill)$/',
+        Notes => 'models other than the SD1 and Merrill models',
         Writable => 'rational64u',
         PrintConv => 'Image::ExifTool::Exif::PrintExposureTime($val)',
         PrintConvInv => 'Image::ExifTool::Exif::ConvertFraction($val)',
@@ -322,8 +404,8 @@ $VERSION = '1.10';
     },
     0x0033 => { #PH
         Name => 'ExposureTime2',
-        Condition => '$$self{Model} !~ / SD(1|9|15)$/',
-        Notes => 'models other than the SD1, SD9 and SD15',
+        Condition => '$$self{Model} !~ / (SD1|SD9|SD15|Merrill)$/',
+        Notes => 'models other than the SD1, SD9, SD15 and Merrill models',
         Writable => 'string',
         ValueConv => '$val * 1e-6',
         ValueConvInv => 'int($val * 1e6 + 0.5)',
@@ -332,15 +414,15 @@ $VERSION = '1.10';
     },
     0x0034 => { #PH
         Name => 'BurstShot',
-        Condition => '$$self{Model} ne "SIGMA SD1"',
-        Notes => 'models other than the SD1',
+        Condition => '$$self{Model} !~ /^SIGMA (SD1( Merrill)?|DP\d Merrill)$/',
+        Notes => 'models other than the SD1 and Merrill models',
         Writable => 'int32u',
     },
     # 0x0034 - int32u: 0,1,2,3 or 4
     0x0035 => { #PH
         Name => 'ExposureCompensation',
-        Condition => '$$self{Model} ne "SIGMA SD1"',
-        Notes => 'models other than the SD1',
+        Condition => '$$self{Model} !~ /^SIGMA (SD1( Merrill)?|DP\d Merrill)$/',
+        Notes => 'models other than the SD1 and Merrill models',
         Writable => 'rational64s',
         # add a '+' sign to positive values
         PrintConv => '$val and $val =~ s/^(\d)/\+$1/; $val',
@@ -350,28 +432,28 @@ $VERSION = '1.10';
     # 0x0037-38 - string: ""
     0x0039 => { #PH (invalid for SD9, SD14?)
         Name => 'SensorTemperature',
-        Condition => '$$self{Model} ne "SIGMA SD1"',
-        Notes => 'models other than the SD1',
+        Condition => '$$self{Model} !~ /^SIGMA (SD1( Merrill)?|DP\d Merrill)$/',
+        Notes => 'models other than the SD1 and Merrill models',
         # (string format)
         PrintConv => 'IsInt($val) ? "$val C" : $val',
         PrintConvInv => '$val=~s/ ?C$//; $val',
     },
     0x003a => { #PH
         Name => 'FlashExposureComp',
-        Condition => '$$self{Model} ne "SIGMA SD1"',
-        Notes => 'models other than the SD1',
+        Condition => '$$self{Model} !~ /^SIGMA (SD1( Merrill)?|DP\d Merrill)$/',
+        Notes => 'models other than the SD1 and Merrill models',
         Writable => 'rational64s',
     },
     0x003b => { #PH (how is this different from other Firmware?)
         Name => 'Firmware',
-        Condition => '$$self{Model} ne "SIGMA SD1"',
-        Notes => 'models other than the SD1',
+        Condition => '$$self{Model} !~ /^SIGMA (SD1( Merrill)?|DP\d Merrill)$/',
+        Notes => 'models other than the SD1 and Merrill models',
         Priority => 0,
     },
     0x003c => { #PH
         Name => 'WhiteBalance',
-        Condition => '$$self{Model} ne "SIGMA SD1"',
-        Notes => 'models other than the SD1',
+        Condition => '$$self{Model} !~ /^SIGMA (SD1( Merrill)?|DP\d Merrill)$/',
+        Notes => 'models other than the SD1 and Merrill models',
         Priority => 0,
     },
     0x003d => { #PH (new for SD15 and SD1)
@@ -380,13 +462,13 @@ $VERSION = '1.10';
     },
     0x0048 => { #PH
         Name => 'LensApertureRange',
-        Condition => '$$self{Model} eq "SIGMA SD1"',
-        Notes => 'SD1 only',
+        Condition => '$$self{Model} =~ /^SIGMA (SD1( Merrill)?|DP\d Merrill)$/',
+        Notes => 'SD1 and Merrill models only',
     },
     0x0049 => { #PH
         Name => 'FNumber',
-        Condition => '$$self{Model} eq "SIGMA SD1"',
-        Notes => 'SD1 only',
+        Condition => '$$self{Model} =~ /^SIGMA (SD1( Merrill)?|DP\d Merrill)$/',
+        Notes => 'SD1 and Merrill models only',
         Writable => 'rational64u',
         PrintConv => 'sprintf("%.1f",$val)',
         PrintConvInv => '$val',
@@ -394,8 +476,8 @@ $VERSION = '1.10';
     },
     0x004a => { #PH
         Name => 'ExposureTime',
-        Condition => '$$self{Model} eq "SIGMA SD1"',
-        Notes => 'SD1 only',
+        Condition => '$$self{Model} =~ /^SIGMA (SD1( Merrill)?|DP\d Merrill)$/',
+        Notes => 'SD1 and Merrill models only',
         Writable => 'rational64u',
         PrintConv => 'Image::ExifTool::Exif::PrintExposureTime($val)',
         PrintConvInv => 'Image::ExifTool::Exif::ConvertFraction($val)',
@@ -403,49 +485,55 @@ $VERSION = '1.10';
     },
     0x004b => { #PH
         Name => 'ExposureTime2',
-        Condition => '$$self{Model} eq "SIGMA SD1"',
-        Notes => 'SD1 only',
+        Condition => '$$self{Model} =~ /^SIGMA (SD1( Merrill)?|DP\d Merrill)$/',
+        Notes => 'SD1 and Merrill models only',
         Writable => 'string',
         PrintConv => 'Image::ExifTool::Exif::PrintExposureTime($val)',
         PrintConvInv => 'Image::ExifTool::Exif::ConvertFraction($val)',
     },
     0x004d => { #PH
         Name => 'ExposureCompensation',
-        Condition => '$$self{Model} eq "SIGMA SD1"',
-        Notes => 'SD1 only',
+        Condition => '$$self{Model} =~ /^SIGMA (SD1( Merrill)?|DP\d Merrill)$/',
+        Notes => 'SD1 and Merrill models only',
         Writable => 'rational64s',
         # add a '+' sign to positive values
         PrintConv => '$val and $val =~ s/^(\d)/\+$1/; $val',
         PrintConvInv => '$val',
     },
+    # 0x0054 - string: "F20"
     0x0055 => { #PH
         Name => 'SensorTemperature',
-        Condition => '$$self{Model} eq "SIGMA SD1"',
-        Notes => 'SD1 only',
+        Condition => '$$self{Model} =~ /^SIGMA (SD1( Merrill)?|DP\d Merrill)$/',
+        Notes => 'SD1 and Merrill models only',
         # (string format)
         PrintConv => 'IsInt($val) ? "$val C" : $val',
         PrintConvInv => '$val=~s/ ?C$//; $val',
     },
     0x0056 => { #PH (NC)
         Name => 'FlashExposureComp',
-        Condition => '$$self{Model} eq "SIGMA SD1"',
-        Notes => 'SD1 only',
+        Condition => '$$self{Model} =~ /^SIGMA (SD1( Merrill)?|DP\d Merrill)$/',
+        Notes => 'SD1 and Merrill models only',
         Writable => 'rational64s',
     },
     0x0057 => { #PH (how is this different from other Firmware?)
         Name => 'Firmware',
-        Condition => '$$self{Model} eq "SIGMA SD1"',
-        Notes => 'SD1 only',
+        Condition => '$$self{Model} =~ /^SIGMA (SD1( Merrill)?|DP\d Merrill)$/',
+        Notes => 'SD1 and Merrill models only',
         Priority => 0,
     },
     0x0058 => { #PH
         Name => 'WhiteBalance',
-        Condition => '$$self{Model} eq "SIGMA SD1"',
-        Notes => 'SD1 only',
+        Condition => '$$self{Model} =~ /^SIGMA (SD1( Merrill)?|DP\d Merrill)$/',
+        Notes => 'SD1 and Merrill models only',
         Priority => 0,
     },
-    # 0x0059 = 'Standard' for the SD1
-    # 0x005a/b/c = 0/10 for the SD1
+    0x0059 => { #PH
+        Name => 'DigitalFilter',
+        Condition => '$$self{Model} =~ /^SIGMA (SD1( Merrill)?|DP\d Merrill)$/',
+        Notes => 'SD1 and Merrill models only',
+        # seen: Standard, Landscape,Monochrome,Neutral,Portrait,Sepia,Vivid
+    },
+    # 0x005a/b/c - rational64s: 0/10 for the SD1
 );
 
 1;  # end
@@ -467,7 +555,7 @@ Sigma and Foveon maker notes in EXIF information.
 
 =head1 AUTHOR
 
-Copyright 2003-2012, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2014, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
